aboutsummaryrefslogtreecommitdiffstats
path: root/src/gqueue/gqueue_rules.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gqueue/gqueue_rules.h')
-rw-r--r--src/gqueue/gqueue_rules.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gqueue/gqueue_rules.h b/src/gqueue/gqueue_rules.h
index ecdea7a9..0d411bc6 100644
--- a/src/gqueue/gqueue_rules.h
+++ b/src/gqueue/gqueue_rules.h
@@ -20,13 +20,13 @@
#if GQUEUE_NEED_BUFFERS && !GQUEUE_NEED_GSYNC
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GQUEUE: GQUEUE_NEED_GSYNC is required if GQUEUE_NEED_BUFFERS is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GQUEUE: GQUEUE_NEED_GSYNC is required if GQUEUE_NEED_BUFFERS is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GQUEUE: GQUEUE_NEED_GSYNC is required if GQUEUE_NEED_BUFFERS is GFXON. It has been turned on for you.")
#endif
#endif
#undef GQUEUE_NEED_GSYNC
- #define GQUEUE_NEED_GSYNC TRUE
+ #define GQUEUE_NEED_GSYNC GFXON
#endif
#endif
@@ -20,13 +20,13 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GQUEUE: GQUEUE_NEED_GSYNC is required if GQUEUE_NEED_BUFFERS is TRUE. It has been turned on for you."
+ #warning "GQUEUE: GQUEUE_NEED_GSYNC is required if GQUEUE_NEED_BUFFERS is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO